@@ -1,7 +1,7 @@
 /*
  *	sleepwatcher
  *
- *	Copyright (c) 2002-2011 Bernhard Baehr
+ *	Copyright (c) 2002-2019 Bernhard Baehr
  *
  *	sleepwatcher.c - sleep mode watchdog program
  *
@@ -189,7 +189,7 @@ static void usage (void)
 		"       exit code, -a without allowsleepcommand denys sleeping\n"
 		"       (note: no space between -a and the optional allowsleepcommand)\n"
 		"-c or --cantsleep\n"
-		"       execute cantsleepcommand when the Mac retracts an attempt to sleep that\n"
+		"       execute cantsleepcommand when the Mac retracts an attempt to sleep\n"
 		"       that previously was allowed via the -a option, but vetoed by an other\n"
 		"       process\n"
                 "-s or --sleep\n"
@@ -233,8 +233,8 @@ static void usage (void)
 
 static void copyright (void)
 {
-	printf ("sleepwatcher 2.2\n"
-		"Copyright (c) 2002-2011 Bernhard Baehr (bernhard.baehr@gmx.de)\n"
+	printf ("sleepwatcher 2.2.1\n"
+		"Copyright (c) 2002-2019 Bernhard Baehr (bernhard.baehr@gmx.de)\n"
 		"This is free software that comes with ABSOLUTELY NO WARRANTY.\n"
 		"See the GNU General Public License for details.\n");
 	exit (2);
@@ -451,13 +451,13 @@ static void readConfig (const char *configfile)
 			*q++ = *p++;				/* '=' */
 		while (*p && isblank(*p))			/* remove blanks before argument */
 			p++;
-		while (*q++ = *p++)				/* unmodified argument string */
+		while ((*q++ = *p++))				/* unmodified argument string */
 			;
 		for (op = longopts; op->name; op++) {
 			l = strlen(op->name);
 			if (! strncmp(op->name, buf, l)) {
-				if (op->has_arg == no_argument && buf[l] ||
-					op->has_arg != no_argument && buf[l] != '=')
+				if ((op->has_arg == no_argument && buf[l]) ||
+					(op->has_arg != no_argument && buf[l] != '='))
 					message (LOG_ERR, "malformed parameter '%s' in config file %s\n", buf, configfile);
 				setOption (op->val, buf + l + 1);
 				break;
@@ -595,7 +595,7 @@ static void hidCallback (void *context, IOReturn result, void *sender, IOHIDValu
 		args.idleresume = 0;
 		message (LOG_INFO, "idleresume: %s: %d\n", args.idleresumecommand, system(args.idleresumecommand));
 	}
-	timeOfLastCall = now;
+	timeOfLastCall = CFAbsoluteTimeGetCurrent();	// don't use "now" because the commands may consume some time
 	setupIdleTimer ();
 }
 
@@ -876,7 +876,7 @@ static void signalCallback (int sig)
 		break;
 	case SIGTERM :
 	case SIGINT :
-		message (LOG_INFO, "got %s - exiting\n", sig == SIGTERM ? "SIGTERM" : "SIGINT");	
+		message (LOG_INFO, "got %s - exiting\n", sig == SIGTERM ? "SIGTERM" : "SIGINT");
 		writePidFile (NULL);
 		exit (0);
 		break;
